{% extends base %} {% block head %}
{% end %} {% block body %}

# HTML4.0标准中浏览器支持的16种颜色

#00FFFF aqua
#000000 black
#0000FF blue
#FF00FF fuchsia
#808080 gray
#008000 green
#00FF00 lime
#800000 maroon
#000080 navy
#808000 olive
#800080 purple
#FF0000 red
#C0C0C0 silver
#008080 teal
#FFFFFF white
#FFFF00 yellow

# 经典配色

#00C1DE 阿里云蓝
#0099CC 安卓蓝1
#039BE5 安卓蓝2
#568900 草绿色
#fff8e8 背景色

# 其他颜色

#FF0000 红色; #00FF00 绿色; #008000 绿色; #0000FF 绿色; #0074bd 蓝色; #0978DD; #CCCCCC 灰色; #BBBBBB; #AAAAAA; #FF8040; #FF8000;
{% end %}